@@ -4,7 +4,7 @@ Data::FreqConvert - converts variables to scalars holfding frequencys of keys in
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 
 =head1 SYNOPSIS
@@ -51,6 +51,18 @@ our $VERSION = "0.01";
       return $self;
   }
 
+  sub  trim  {
+
+    my  $string  =  shift;
+    $string  =  ""  unless  $string;
+    $string  =~  s/^\s+//;
+    $string  =~  s/\s+$//;
+    $string  =~  s/\t//;
+    $string  =~  s/^\s//;
+    $string  =~  s/^->//;
+    $string  =~  s/^=>//;
+    return  $string;
+  }
 
   sub prepArg {
       my $self = shift;
@@ -61,12 +73,11 @@ our $VERSION = "0.01";
       if($ref =~ /HASH/) {
           @return = keys %$arg;
       }
-      if($ref =~ /ARRAY/) {
+      elsif($ref =~ /ARRAY/) {
           @return = @$arg;
-      }
+      }else{
 
-      if($ref eq "") {
-          @return = split("\n",$arg);
+      @return = split("\n",$arg);
       }
 
       return @return;
@@ -75,8 +86,7 @@ our $VERSION = "0.01";
 
 
   sub freq {
-      my $self = shift;
-      my $arg = shift;
+      my ($self,$arg) = @_;
       my @set = $self->prepArg($arg);
       my $data = Data::Freq->new();
       foreach my $n( @set){
@@ -92,17 +102,21 @@ our $VERSION = "0.01";
     my @buffer =  reverse grep{/\w|\d/}$capture->read;
 
     my $last = "";
-    my $i = 0;
     foreach my $z(@buffer){
-         if($z=~/\w/ && ($i % 2 || $i == 0)) {
+
+         $z = trim($z);
+
+         if($z !~ m/^\d/) {
             $ret->{$z}="";
+            $last = $z;
          }
+
          else {
          $ret->{$last}=$z;
          }
 
-         $last = $z;
-         $i++;
+
+
     }
 
     return $ret;
